==> fantacalciobazar_0.2.tar.gz: fantacalciobazar/controlla_pass.php <==
<?php

################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
################################################################################

include("dati.php");
$pass_admin_errata = "SI";
if ($nome_utente == "admin") {
$pass_errata = "SI";
if ($passadmin == "nopasswordinserita") { $password = ""; }
else { $password = $passadmin; }
if ($pass_fornita == $password) {
$pass_admin_errata = "NO";
} # fine if ($pass_fornita == $password)
} # fine if ($nome_utente == "admin")
else {
if (!$pass[$nome_utente]) {
echo "Nome utente o password errati.<br>";
$pass_errata = "SI";
} # fine if (!$pass[$nome_utente])
if ($pass[$nome_utente] == "nopasswordinserita") { $password = ""; }
else { $password = $pass[$nome_utente]; }
if ($pass_fornita != $password) {
echo "Nome utente o password errati.<br>";
$pass_errata = "SI";
} # fine if ($pass_fornita != $password)
} # fine else if ($nome_utente == "admin")

?>

==> fantacalciobazar_0.3.tar.gz: fantacalciobazar/controlla_pass.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

include("dati/dati.php");
$pass_admin_errata = "SI";
if ($nome_utente == "admin") {
$pass_errata = "SI";
if ($passadmin == "nopasswordinserita") { $password = ""; }
else { $password = $passadmin; }
if ($pass_fornita == $password) {
$pass_admin_errata = "NO";
} # fine if ($pass_fornita == $password)
} # fine if ($nome_utente == "admin")
else {
if (!$pass[$nome_utente]) {
echo "Nome utente o password errati.<br>";
$pass_errata = "SI";
} # fine if (!$pass[$nome_utente])
if ($pass[$nome_utente] == "nopasswordinserita") { $password = ""; }
else { $password = $pass[$nome_utente]; }
if ($pass_fornita != $password) {
echo "Nome utente o password errati.<br>";
$pass_errata = "SI";
} # fine if ($pass_fornita != $password)
} # fine else if ($nome_utente == "admin")

?>
